<p align="center">
  <img src="https://github.com/kaliv0/fumus/blob/main/assets/fumus.gif?raw=true" width="400" alt="Fumus">
</p>

# FUMUS
## Functional Musings in Python


![Python 3.x](https://img.shields.io/badge/python-3.12-blue?style=flat-square&logo=Python&logoColor=white)
[![tests](https://img.shields.io/github/actions/workflow/status/kaliv0/fumus/ci.yml)](https://github.com/kaliv0/fumus/actions/workflows/ci.yml)
[![PyPI](https://img.shields.io/pypi/v/fumus.svg)](https://pypi.org/project/fumus/)
[![docs](https://readthedocs.org/projects/fumus/badge/?version=latest)](https://fumus.readthedocs.io/en/latest)
[![Downloads](https://static.pepy.tech/badge/fumus)](https://pepy.tech/projects/fumus)

<br><b>Yet another <i>functional-style</i> Queries library for processing collections and iterables using <i>fluent APIs</i></b><br>